@@ -128,7 +128,6 @@ class TenRoster(Roster):
 class MLBRoster(Roster):
     POSITION_ORDER = {
         'P': 0,
-        'RP': 0,
         'SP': 0,
         'C': 1,
         '1B': 2,
@@ -136,6 +135,7 @@ class MLBRoster(Roster):
         '3B': 4,
         'SS': 5,
         'OF': 6,
+        'RP': 7,
     }
 
 
@@ -355,12 +355,6 @@ class Player(object):
             return 'F'
         return 'C'
 
-    @property
-    def mlb_general_position(self):
-        if self.pos in {'SP', 'RP'}:
-            return 'P'
-        return self.pos
-
     @property
     def short_name(self):
         s = self.name.split()
